@@ -6,11 +6,13 @@ The :mod:`pyro.contrib.autoname` module provides tools for automatically
 generating unique, semantically meaningful names for sample sites.
 """
 from pyro.contrib.autoname import named
-from pyro.contrib.autoname.scoping import scope, name_count
-
+from pyro.contrib.autoname.autoname import autoname, sample
+from pyro.contrib.autoname.scoping import name_count, scope
 
 __all__ = [
     "named",
     "scope",
     "name_count",
+    "autoname",
+    "sample",
 ]
