@@ -14,7 +14,7 @@ import urllib
 
 import torch
 
-from pyro.contrib.examples.util import get_data_directory, _mkdir_p
+from pyro.contrib.examples.util import _mkdir_p, get_data_directory
 
 DATA = get_data_directory(__file__)
 
@@ -122,16 +122,19 @@ def load_bart_od():
     if os.path.exists(pkl_file):
         return torch.load(pkl_file)
 
-    filenames = multiprocessing.Pool(len(SOURCE_FILES)).map(_load_hourly_od, SOURCE_FILES)
+    filenames = multiprocessing.Pool(len(SOURCE_FILES)).map(
+        _load_hourly_od, SOURCE_FILES
+    )
     datasets = list(map(torch.load, filenames))
 
     stations = sorted(set().union(*(d["stations"].keys() for d in datasets)))
     min_time = min(int(d["rows"][:, 0].min()) for d in datasets)
     max_time = max(int(d["rows"][:, 0].max()) for d in datasets)
     num_rows = max_time - min_time + 1
-    start_date = datasets[0]["start_date"] + datetime.timedelta(hours=min_time),
-    logging.info("Loaded data from {} stations, {} hours"
-                 .format(len(stations), num_rows))
+    start_date = (datasets[0]["start_date"] + datetime.timedelta(hours=min_time),)
+    logging.info(
+        "Loaded data from {} stations, {} hours".format(len(stations), num_rows)
+    )
 
     result = torch.zeros(num_rows, len(stations), len(stations))
     for dataset in datasets:
@@ -143,8 +146,9 @@ def load_bart_od():
         count = dataset["rows"][:, 3].float()
         result[time, origin, destin] = count
         dataset.clear()
-    logging.info("Loaded {} shaped data of mean {:0.3g}"
-                 .format(result.shape, result.mean()))
+    logging.info(
+        "Loaded {} shaped data of mean {:0.3g}".format(result.shape, result.mean())
+    )
 
     dataset = {
         "stations": stations,
@@ -174,6 +178,8 @@ if __name__ == "__main__":
     parser.add_argument("-v", "--verbose", action="store_true")
     args = parser.parse_args()
 
-    logging.basicConfig(format='%(relativeCreated) 9d %(message)s',
-                        level=logging.DEBUG if args.verbose else logging.INFO)
+    logging.basicConfig(
+        format="%(relativeCreated) 9d %(message)s",
+        level=logging.DEBUG if args.verbose else logging.INFO,
+    )
     load_bart_od()
