@@ -32,7 +32,7 @@ class VariationalGP(GPModel):
     be learned during a variational inference process.
 
     .. note:: This model can be seen as a special version of
-        :class:`.SparseVariationalGP` model with :math:`X_u = X`.
+        :class:`.VariationalSparseGP` model with :math:`X_u = X`.
 
     .. note:: This model has :math:`\mathcal{O}(N^3)` complexity for training,
         :math:`\mathcal{O}(N^3)` complexity for testing. Here, :math:`N` is the number
@@ -71,6 +71,13 @@ class VariationalGP(GPModel):
         whiten=False,
         jitter=1e-6,
     ):
+        assert isinstance(
+            X, torch.Tensor
+        ), "X needs to be a torch Tensor instead of a {}".format(type(X))
+        if y is not None:
+            assert isinstance(
+                y, torch.Tensor
+            ), "y needs to be a torch Tensor instead of a {}".format(type(y))
         super().__init__(X, y, kernel, mean_function, jitter)
 
         self.likelihood = likelihood
