@@ -60,10 +60,17 @@ class ConstantConditionalTransform(ConditionalTransform):
 
 class ConditionalTransformedDistribution(ConditionalDistribution):
     def __init__(self, base_dist, transforms):
-        self.base_dist = base_dist if isinstance(
-            base_dist, ConditionalDistribution) else ConstantConditionalDistribution(base_dist)
-        self.transforms = [t if isinstance(t, ConditionalTransform)
-                           else ConstantConditionalTransform(t) for t in transforms]
+        self.base_dist = (
+            base_dist
+            if isinstance(base_dist, ConditionalDistribution)
+            else ConstantConditionalDistribution(base_dist)
+        )
+        self.transforms = [
+            t
+            if isinstance(t, ConditionalTransform)
+            else ConstantConditionalTransform(t)
+            for t in transforms
+        ]
 
     def condition(self, context):
         base_dist = self.base_dist.condition(context)
