@@ -39,28 +39,37 @@ class MixtureOfDiagNormals(TorchDistribution):
     :param torch.Tensor coord_scale: K x D scale matrix
     :param torch.Tensor component_logits: K-dimensional vector of softmax logits
     """
+
     has_rsample = True
-    arg_constraints = {"locs": constraints.real, "coord_scale": constraints.positive,
-                       "component_logits": constraints.real}
+    arg_constraints = {
+        "locs": constraints.real,
+        "coord_scale": constraints.positive,
+        "component_logits": constraints.real,
+    }
 
     def __init__(self, locs, coord_scale, component_logits):
-        self.batch_mode = (locs.dim() > 2)
-        assert(coord_scale.shape == locs.shape)
-        assert(self.batch_mode or locs.dim() == 2), \
-            "The locs parameter in MixtureOfDiagNormals should be K x D dimensional (or B x K x D if doing batches)"
+        self.batch_mode = locs.dim() > 2
+        assert coord_scale.shape == locs.shape
+        assert (
+            self.batch_mode or locs.dim() == 2
+        ), "The locs parameter in MixtureOfDiagNormals should be K x D dimensional (or B x K x D if doing batches)"
         if not self.batch_mode:
-            assert(coord_scale.dim() == 2), \
-                "The coord_scale parameter in MixtureOfDiagNormals should be K x D dimensional"
-            assert(component_logits.dim() == 1), \
-                "The component_logits parameter in MixtureOfDiagNormals should be K dimensional"
-            assert(component_logits.size(-1) == locs.size(-2))
+            assert (
+                coord_scale.dim() == 2
+            ), "The coord_scale parameter in MixtureOfDiagNormals should be K x D dimensional"
+            assert (
+                component_logits.dim() == 1
+            ), "The component_logits parameter in MixtureOfDiagNormals should be K dimensional"
+            assert component_logits.size(-1) == locs.size(-2)
             batch_shape = ()
         else:
-            assert(coord_scale.dim() > 2), \
-                "The coord_scale parameter in MixtureOfDiagNormals should be B x K x D dimensional"
-            assert(component_logits.dim() > 1), \
-                "The component_logits parameter in MixtureOfDiagNormals should be B x K dimensional"
-            assert(component_logits.size(-1) == locs.size(-2))
+            assert (
+                coord_scale.dim() > 2
+            ), "The coord_scale parameter in MixtureOfDiagNormals should be B x K x D dimensional"
+            assert (
+                component_logits.dim() > 1
+            ), "The component_logits parameter in MixtureOfDiagNormals should be B x K dimensional"
+            assert component_logits.size(-1) == locs.size(-2)
             batch_shape = tuple(locs.shape[:-2])
 
         self.locs = locs
@@ -69,8 +78,9 @@ class MixtureOfDiagNormals(TorchDistribution):
         self.dim = locs.size(-1)
         self.categorical = Categorical(logits=component_logits)
         self.probs = self.categorical.probs
-        super().__init__(batch_shape=torch.Size(batch_shape),
-                         event_shape=torch.Size((self.dim,)))
+        super().__init__(
+            batch_shape=torch.Size(batch_shape), event_shape=torch.Size((self.dim,))
+        )
 
     def expand(self, batch_shape, _instance=None):
         new = self._get_checked_instance(MixtureOfDiagNormals, _instance)
@@ -78,11 +88,17 @@ class MixtureOfDiagNormals(TorchDistribution):
         batch_shape = torch.Size(batch_shape)
         new.dim = self.dim
         new.locs = self.locs.expand(batch_shape + self.locs.shape[-2:])
-        new.coord_scale = self.coord_scale.expand(batch_shape + self.coord_scale.shape[-2:])
-        new.component_logits = self.component_logits.expand(batch_shape + self.component_logits.shape[-1:])
+        new.coord_scale = self.coord_scale.expand(
+            batch_shape + self.coord_scale.shape[-2:]
+        )
+        new.component_logits = self.component_logits.expand(
+            batch_shape + self.component_logits.shape[-1:]
+        )
         new.categorical = self.categorical.expand(batch_shape)
         new.probs = self.probs.expand(batch_shape + self.probs.shape[-1:])
-        super(MixtureOfDiagNormals, new).__init__(batch_shape, self.event_shape, validate_args=False)
+        super(MixtureOfDiagNormals, new).__init__(
+            batch_shape, self.event_shape, validate_args=False
+        )
         new._validate_args = self._validate_args
         return new
 
@@ -91,7 +107,11 @@ class MixtureOfDiagNormals(TorchDistribution):
         eps_sqr = 0.5 * torch.pow(epsilon, 2.0).sum(-1)  # L B K
         eps_sqr_min = torch.min(eps_sqr, -1)[0]  # L B K
         coord_scale_prod_log_sum = self.coord_scale.log().sum(-1)  # B K
-        result = self.categorical.logits + (-eps_sqr + eps_sqr_min.unsqueeze(-1)) - coord_scale_prod_log_sum  # L B K
+        result = (
+            self.categorical.logits
+            + (-eps_sqr + eps_sqr_min.unsqueeze(-1))
+            - coord_scale_prod_log_sum
+        )  # L B K
         result = torch.logsumexp(result, dim=-1)  # L B
         result = result - 0.5 * math.log(2.0 * math.pi) * float(self.dim)
         result = result - eps_sqr_min
@@ -99,9 +119,14 @@ class MixtureOfDiagNormals(TorchDistribution):
 
     def rsample(self, sample_shape=torch.Size()):
         which = self.categorical.sample(sample_shape)
-        return _MixDiagNormalSample.apply(self.locs, self.coord_scale,
-                                          self.component_logits, self.categorical.probs, which,
-                                          sample_shape + self.locs.shape[:-2] + (self.dim,))
+        return _MixDiagNormalSample.apply(
+            self.locs,
+            self.coord_scale,
+            self.component_logits,
+            self.categorical.probs,
+            which,
+            sample_shape + self.locs.shape[:-2] + (self.dim,),
+        )
 
 
 class _MixDiagNormalSample(Function):
@@ -144,7 +169,9 @@ class _MixDiagNormalSample(Function):
 
         mu_ll_cd = (locs.unsqueeze(-2) * mu_cd).sum(-1)  # b c d
         z_ll_cd = (z.unsqueeze(-2).unsqueeze(-2) * mu_cd).sum(-1)  # l b c d
-        z_perp_cd = z.unsqueeze(-2).unsqueeze(-2) - z_ll_cd.unsqueeze(-1) * mu_cd  # l b c d i
+        z_perp_cd = (
+            z.unsqueeze(-2).unsqueeze(-2) - z_ll_cd.unsqueeze(-1) * mu_cd
+        )  # l b c d i
         z_perp_cd_sqr = torch.pow(z_perp_cd, 2.0).sum(-1)  # l b c d
 
         shift_indices = torch.empty((dim,), dtype=torch.long, device=z.device)
@@ -153,7 +180,9 @@ class _MixDiagNormalSample(Function):
         shift_indices[0] = 0
 
         z_shift_cumsum = torch.pow(z_shift, 2.0)
-        z_shift_cumsum = z_shift_cumsum.sum(-1, keepdim=True) - torch.cumsum(z_shift_cumsum, dim=-1)  # l b j i
+        z_shift_cumsum = z_shift_cumsum.sum(-1, keepdim=True) - torch.cumsum(
+            z_shift_cumsum, dim=-1
+        )  # l b j i
         z_tilde_cumsum = torch.cumsum(torch.pow(z_tilde, 2.0), dim=-1)  # l b j i
         z_tilde_cumsum = torch.index_select(z_tilde_cumsum, -1, shift_indices)
         z_tilde_cumsum[..., 0] = 0.0
@@ -161,7 +190,9 @@ class _MixDiagNormalSample(Function):
 
         log_scales = torch.log(scales)  # b j i
         epsilons_sqr = torch.pow(z_tilde, 2.0)  # l b j i
-        log_qs = -0.5 * epsilons_sqr - 0.5 * math.log(2.0 * math.pi) - log_scales  # l b j i
+        log_qs = (
+            -0.5 * epsilons_sqr - 0.5 * math.log(2.0 * math.pi) - log_scales
+        )  # l b j i
         log_q_j = log_qs.sum(-1, keepdim=True)  # l b j 1
         q_j = torch.exp(log_q_j)  # l b j 1
         q_tot = (pis * q_j.squeeze(-1)).sum(-1)  # l b
@@ -172,13 +203,19 @@ class _MixDiagNormalSample(Function):
         shift_log_scales[..., 0] = 0.0
         sigma_products = torch.cumsum(shift_log_scales, dim=-1).exp()  # b j i
 
-        reverse_indices = torch.tensor(range(dim - 1, -1, -1), dtype=torch.long, device=z.device)
+        reverse_indices = torch.tensor(
+            range(dim - 1, -1, -1), dtype=torch.long, device=z.device
+        )
         reverse_log_sigma_0 = sigma_0.log()[..., reverse_indices]  # b 1 i
-        sigma_0_products = torch.cumsum(reverse_log_sigma_0, dim=-1).exp()[..., reverse_indices - 1]  # b 1 i
+        sigma_0_products = torch.cumsum(reverse_log_sigma_0, dim=-1).exp()[
+            ..., reverse_indices - 1
+        ]  # b 1 i
         sigma_0_products[..., -1] = 1.0
         sigma_products *= sigma_0_products
 
-        logits_grad = torch.erf(z_tilde / root_two) - torch.erf(z_shift / root_two)  # l b j i
+        logits_grad = torch.erf(z_tilde / root_two) - torch.erf(
+            z_shift / root_two
+        )  # l b j i
         logits_grad *= torch.exp(-0.5 * r_sqr_ji)  # l b j i
         logits_grad = (logits_grad * g / sigma_products).sum(-1)  # l b j
         logits_grad = sum_leftmost(logits_grad / q_tot, -1 - batch_dims)  # b j
@@ -187,10 +224,17 @@ class _MixDiagNormalSample(Function):
         logits_grad = logits_grad - logits_grad.sum(-1, keepdim=True) * pis
 
         mu_ll_dc = torch.transpose(mu_ll_cd, -1, -2)
-        v_cd = torch.erf((z_ll_cd - mu_ll_cd) / root_two) - torch.erf((z_ll_cd + mu_ll_dc) / root_two)
+        v_cd = torch.erf((z_ll_cd - mu_ll_cd) / root_two) - torch.erf(
+            (z_ll_cd + mu_ll_dc) / root_two
+        )
         v_cd *= torch.exp(-0.5 * z_perp_cd_sqr)  # l b c d
         mu_cd_g = (g.unsqueeze(-2) * mu_cd).sum(-1)  # l b c d
-        v_cd *= -mu_cd_g * pis.unsqueeze(-2) * 0.5 * math.pow(2.0 * math.pi, -0.5 * (dim - 1))  # l b c d
+        v_cd *= (
+            -mu_cd_g
+            * pis.unsqueeze(-2)
+            * 0.5
+            * math.pow(2.0 * math.pi, -0.5 * (dim - 1))
+        )  # l b c d
         v_cd = pis * sum_leftmost(v_cd.sum(-1) / q_tot, -1 - batch_dims)
         logits_grad += v_cd
 
