@@ -2,6 +2,7 @@
 # SPDX-License-Identifier: Apache-2.0
 
 import torch
+import torch.nn.functional as F
 
 from pyro.ops.gamma_gaussian import (
     GammaGaussian,
@@ -15,6 +16,7 @@ from pyro.ops.gaussian import (
     matrix_and_mvn_to_gaussian,
     mvn_to_gaussian,
 )
+from pyro.ops.indexing import Vindex
 from pyro.ops.special import safe_log
 from pyro.ops.tensor_utils import cholesky, cholesky_solve
 
@@ -46,7 +48,7 @@ def _linear_integrate(init, trans, shift):
 
 def _logmatmulexp(x, y):
     """
-    Numerically stable version of ``(x.log() @ y.log()).exp()``.
+    Numerically stable version of ``(x.exp() @ y.exp()).log()``.
     """
     finfo = torch.finfo(x.dtype)  # avoid nan due to -inf - -inf
     x_shift = x.detach().max(-1, keepdim=True).values.clamp_(min=finfo.min)
@@ -81,6 +83,82 @@ def _sequential_logmatmulexp(logits):
     return logits.squeeze(-3)
 
 
+def _markov_index(x, y):
+    """
+    Join ends of two Markov paths.
+    """
+    y = Vindex(y.unsqueeze(-2))[..., x[..., -1:, :]]
+    return torch.cat([x, y], -2)
+
+
+def _sequential_index(samples):
+    """
+    For a tensor ``samples`` whose time dimension is -2 and state dimension
+    is -1, compute Markov paths by sequential indexing.
+
+    For example, for ``samples`` with 3 states and time duration 5::
+
+        tensor([[0, 1, 1],
+                [1, 0, 2],
+                [2, 1, 0],
+                [0, 2, 1],
+                [1, 1, 0]])
+
+    computed paths are::
+
+        tensor([[0, 1, 1],
+                [1, 0, 0],
+                [1, 2, 2],
+                [2, 1, 1],
+                [0, 1, 1]])
+
+        # path for a 0th state
+        #
+        # 0 1 1
+        # |
+        # 1 0 2
+        #  \
+        # 2 1 0
+        #   |
+        # 0 2 1
+        #    \
+        # 1 1 0
+        #
+        # paths for 1st and 2nd states
+        #
+        # 0 1 1
+        #   |/
+        # 1 0 2
+        #  /
+        # 2 1 0
+        #  \
+        #    \
+        # 0 2 1
+        #    /
+        # 1 1 0
+    """
+    # new Markov time dimension at -2
+    samples = samples.unsqueeze(-2)
+    batch_shape = samples.shape[:-3]
+    state_dim = samples.size(-1)
+    duration = samples.size(-3)
+    while samples.size(-3) > 1:
+        time = samples.size(-3)
+        even_time = time // 2 * 2
+        even_part = samples[..., :even_time, :, :]
+        x_y = even_part.reshape(batch_shape + (even_time // 2, 2, -1, state_dim))
+        x, y = x_y.unbind(-3)
+        contracted = _markov_index(x, y)
+        if time > even_time:
+            padded = F.pad(
+                input=samples[..., -1:, :, :],
+                pad=(0, 0, 0, contracted.size(-2) // 2),
+            )
+            contracted = torch.cat((contracted, padded), dim=-3)
+        samples = contracted
+    return samples.squeeze(-3)[..., :duration, :]
+
+
 def _sequential_gaussian_tensordot(gaussian):
     """
     Integrates a Gaussian ``x`` whose rightmost batch dimension is time, computes::
@@ -272,8 +350,10 @@ class HiddenMarkovModel(TorchDistribution):
 class DiscreteHMM(HiddenMarkovModel):
     """
     Hidden Markov Model with discrete latent state and arbitrary observation
-    distribution. This uses [1] to parallelize over time, achieving
-    O(log(time)) parallel complexity.
+    distribution.
+
+    This uses [1] to parallelize over time, achieving O(log(time)) parallel
+    complexity for computing :meth:`log_prob`, :meth:`filter`, and :meth:`sample`.
 
     The event_shape of this distribution includes time on the left::
 
@@ -423,6 +503,40 @@ class DiscreteHMM(HiddenMarkovModel):
         # Convert to a distribution.
         return Categorical(logits=logp, validate_args=self._validate_args)
 
+    @torch.no_grad()
+    def sample(self, sample_shape=torch.Size()):
+        assert self.duration is not None
+
+        # Sample initial state.
+        S = self.initial_logits.size(-1)  # state space size
+        init_shape = torch.Size(sample_shape) + self.batch_shape + (S,)
+        init_logits = self.initial_logits.expand(init_shape)
+        x = Categorical(logits=init_logits).sample()
+
+        # Sample hidden states over time.
+        trans_shape = (
+            torch.Size(sample_shape) + self.batch_shape + (self.duration, S, S)
+        )
+        trans_logits = self.transition_logits.expand(trans_shape)
+        xs = Categorical(logits=trans_logits).sample()
+        xs = _sequential_index(xs)
+        x = Vindex(xs)[..., :, x]
+
+        # Sample observations conditioned on hidden states.
+        # Note the simple sample-then-slice approach here generalizes to all
+        # distributions, but is inefficient. To implement a general optimal
+        # slice-then-sample strategy would require distributions to support
+        # slicing https://github.com/pyro-ppl/pyro/issues/3052. A simpler
+        # implementation might register a few slicing operators as is done with
+        # pyro.contrib.forecast.util.reshape_batch(). If you as a user need
+        # this function to be cheaper, feel free to submit a PR implementing
+        # one of these approaches.
+        obs_shape = self.batch_shape + (self.duration, S)
+        obs_dist = self.observation_dist.expand(obs_shape)
+        y = obs_dist.sample(sample_shape)
+        y = Vindex(y)[(Ellipsis, x) + (slice(None),) * obs_dist.event_dim]
+        return y
+
 
 class GaussianHMM(HiddenMarkovModel):
     """
