@@ -2,8 +2,8 @@
 # SPDX-License-Identifier: Apache-2.0
 
 from pyro.infer.mcmc.adaptation import ArrowheadMassMatrix, BlockMassMatrix
+from pyro.infer.mcmc.api import MCMC, StreamingMCMC
 from pyro.infer.mcmc.hmc import HMC
-from pyro.infer.mcmc.api import MCMC
 from pyro.infer.mcmc.nuts import NUTS
 
 __all__ = [
@@ -12,4 +12,5 @@ __all__ = [
     "HMC",
     "MCMC",
     "NUTS",
+    "StreamingMCMC",
 ]
