@@ -4,8 +4,12 @@
 import functools
 import math
 import operator
+import weakref
+from typing import Dict
 
+import numpy as np
 import torch
+from numpy.polynomial.hermite import hermgauss
 
 
 class _SafeLog(torch.autograd.Function):
@@ -151,3 +155,64 @@ def log_I1(orders: int, value: torch.Tensor, terms=250):
     i1s = lvalues[..., :orders].T + seqs
     assert i1s.shape == (orders, vshape.numel())
     return i1s.view(-1, *vshape)
+
+
+def get_quad_rule(num_quad, prototype_tensor):
+    r"""
+    Get quadrature points and corresponding log weights for a Gauss Hermite quadrature rule
+    with the specified number of quadrature points.
+
+    Example usage::
+
+        quad_points, log_weights = get_quad_rule(32, prototype_tensor)
+        # transform to N(0, 4.0) Normal distribution
+        quad_points *= 4.0
+        # compute variance integral in log-space using logsumexp and exponentiate
+        variance = torch.logsumexp(quad_points.pow(2.0).log() + log_weights, axis=0).exp()
+        assert (variance - 16.0).abs().item() < 1.0e-6
+
+    :param int num_quad: number of quadrature points.
+    :param torch.Tensor prototype_tensor: used to determine `dtype` and `device` of returned tensors.
+    :return: tuple of `torch.Tensor`s of the form `(quad_points, log_weights)`
+    """
+    quad_rule = hermgauss(num_quad)
+    quad_points = quad_rule[0] * np.sqrt(2.0)
+    log_weights = np.log(quad_rule[1]) - 0.5 * np.log(np.pi)
+    return torch.from_numpy(quad_points).type_as(prototype_tensor), torch.from_numpy(
+        log_weights
+    ).type_as(prototype_tensor)
+
+
+def sparse_multinomial_likelihood(total_count, nonzero_logits, nonzero_value):
+    """
+    The following are equivalent::
+
+        # Version 1. dense
+        log_prob = Multinomial(logits=logits).log_prob(value).sum()
+
+        # Version 2. sparse
+        nnz = value.nonzero(as_tuple=True)
+        log_prob = sparse_multinomial_likelihood(
+            value.sum(-1),
+            (logits - logits.logsumexp(-1))[nnz],
+            value[nnz],
+        )
+    """
+    return (
+        _log_factorial_sum(total_count)
+        - _log_factorial_sum(nonzero_value)
+        + torch.dot(nonzero_logits, nonzero_value)
+    )
+
+
+_log_factorial_cache: Dict[int, torch.Tensor] = {}
+
+
+def _log_factorial_sum(x: torch.Tensor) -> torch.Tensor:
+    if x.requires_grad:
+        return (x + 1).lgamma().sum()
+    key = id(x)
+    if key not in _log_factorial_cache:
+        weakref.finalize(x, _log_factorial_cache.pop, key, None)  # type: ignore
+        _log_factorial_cache[key] = (x + 1).lgamma().sum()
+    return _log_factorial_cache[key]
