@@ -3,8 +3,6 @@
 
 import torch
 
-from pyro.util import ignore_jit_warnings
-
 from .messenger import Messenger
 
 
@@ -18,18 +16,21 @@ class MaskMessenger(Messenger):
         (1 includes a site, 0 excludes a site)
     :returns: stochastic function decorated with a :class:`~pyro.poutine.scale_messenger.MaskMessenger`
     """
+
     def __init__(self, mask):
         if isinstance(mask, torch.Tensor):
             if mask.dtype != torch.bool:
-                raise ValueError('Expected mask to be a BoolTensor but got {}'.format(type(mask)))
-        else:
-            if mask not in (True, False):
-                raise ValueError('Expected mask to be a boolean but got {}'.format(type(mask)))
-            with ignore_jit_warnings():
-                mask = torch.tensor(mask)
+                raise ValueError(
+                    "Expected mask to be a BoolTensor but got {}".format(type(mask))
+                )
+
+        elif mask not in (True, False):
+            raise ValueError(
+                "Expected mask to be a boolean but got {}".format(type(mask))
+            )
         super().__init__()
         self.mask = mask
 
     def _process_message(self, msg):
-        msg["mask"] = self.mask if msg["mask"] is None else self.mask & msg["mask"]
+        msg["mask"] = self.mask if msg["mask"] is None else msg["mask"] & self.mask
         return None
